summaryrefslogtreecommitdiff
path: root/include/svx/dbaexchange.hxx
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-03-12 14:53:28 +0200
committerNoel Grandin <noel@peralex.com>2015-03-18 14:23:50 +0200
commitfb14be5f8f74f83ba89e15f891ddf1f753dcc62f (patch)
treebeaa4af08b0c3d75bf6e40b21b96c55e0ac1c60a /include/svx/dbaexchange.hxx
parentb8ce52aab9459773544f1696cfe6b7b6f171a389 (diff)
create new 'enum class' SotClipboardFormatId to unify types
of which there are several. There are some issues here I am unsure of - the SW and SC and CHART2 modules essentially ignore the enum values and assign their own ids Perhaps I should change them to use the common values and create new enum values where necessary? - the sc/qa/ and sq/qa/ and starmath/qa/ code was doing some dodgy stuff. I translated the code to pass down the stuff numeric values to the underlying code, but perhaps further fixing is necessary? Change-Id: Ic06d723e404481e3f1bca67c43b70321b764d923
Diffstat (limited to 'include/svx/dbaexchange.hxx')
-rw-r--r--include/svx/dbaexchange.hxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/svx/dbaexchange.hxx b/include/svx/dbaexchange.hxx
index 5c5cba8bb8e4..eed5b2c46c8c 100644
--- a/include/svx/dbaexchange.hxx
+++ b/include/svx/dbaexchange.hxx
@@ -149,7 +149,7 @@ namespace svx
virtual void AddSupportedFormats() SAL_OVERRIDE;
virtual bool GetData( const css::datatransfer::DataFlavor& rFlavor, const OUString& rDestDoc ) SAL_OVERRIDE;
- static sal_uInt32 getDescriptorFormatId();
+ static SotClipboardFormatId getDescriptorFormatId();
private:
SVX_DLLPRIVATE void implConstruct(
@@ -170,7 +170,7 @@ namespace svx
{
ODataAccessDescriptor m_aDescriptor;
OUString m_sCompatibleObjectDescription;
// needed to provide a SOT_FORMATSTR_ID_SBA_DATAEXCHANGE format
public:
/** should be used copying and the connection is needed.
@@ -277,7 +277,7 @@ namespace svx
virtual void AddSupportedFormats() SAL_OVERRIDE;
virtual bool GetData( const css::datatransfer::DataFlavor& rFlavor, const OUString& rDestDoc ) SAL_OVERRIDE;
virtual void ObjectReleased() SAL_OVERRIDE;
- static sal_uInt32 getDescriptorFormatId();
+ static SotClipboardFormatId getDescriptorFormatId();
};
@@ -170,7 +170,7 @@ namespace svx
ODataAccessDescriptor m_aDescriptor;
OUString m_sCompatibleObjectDescription;
- // needed to provide a SOT_FORMATSTR_ID_SBA_DATAEXCHANGE format
+ // needed to provide a SotClipboardFormatId::SBA_DATAEXCHANGE format
public:
/** should be used copying and the connection is needed.